==> gmssl-sdf-crypto-0.1-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfECKeyParameters.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.core.utils.GMSSLByteArrayUtils;
import com.xdja.pki.gmssl.sdf.SdfSDK;
import com.xdja.pki.gmssl.sdf.SdfSDKException;
import com.xdja.pki.gmssl.sdf.bean.SdfECCPublicKey;
import com.xdja.pki.gmssl.sdf.yunhsum.YunhsumSdfSDK;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.bouncycastle.util.BigIntegers;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigInteger;
import java.security.interfaces.ECPublicKey;
import java.security.spec.ECPoint;

public class SdfECKeyParameters extends AsymmetricKeyParameter {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    private ECPublicKey publicKey;
    private SdfPrivateKey privateKey;

    /**
     * for
     * 1. sm2 engine encrypt
     * 2. sm2 signer verify
     *
     * @param publicKey public key
     */
    public SdfECKeyParameters(ECPublicKey publicKey) {
        super(false);
        this.publicKey = publicKey;
    }

    /**
     * for
     * 1. sm2 engine decrypt
     * 2. sm2 signer sign
     *
     * @param privateKey private key with sdf index and password
     */
    public SdfECKeyParameters(SdfPrivateKey privateKey) {
        super(true);
        this.privateKey = privateKey;
    }

    public ECPoint getQ() {
        return this.publicKey.getW();
    }

    public SdfECCPublicKey getSDFECCPublicKey() {
        if (this.publicKey != null) {
            return SdfECCPublicKey.getInstance(this.publicKey);
        } else {
            return null;
        }
    }

    public int getSm2Index() {
        return this.privateKey.getSm2Index();
    }

    public byte[] getPassword() {
        return this.privateKey.getPassword();
    }
}

==> gmssl-sdf-crypto-2.0.2-20240506.015439-6-sources.jar: com/xdja/pki/gmssl/crypto/sdf/SdfECKeyParameters.java <==
package com.xdja.pki.gmssl.crypto.sdf;

import com.xdja.pki.gmssl.sdf.bean.SdfECCPublicKey;
import org.bouncycastle.crypto.params.AsymmetricKeyParameter;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.security.interfaces.ECPublicKey;
import java.security.spec.ECPoint;

public class SdfECKeyParameters extends AsymmetricKeyParameter {

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    private ECPublicKey publicKey;
    private SdfPrivateKey privateKey;
    private int bits = 256;

    /**
     * for
     * 1. sm2 engine encrypt
     * 2. sm2 signer verify
     *
     * @param publicKey public key
     */
    public SdfECKeyParameters(ECPublicKey publicKey) {
        super(false);
        this.publicKey = publicKey;
    }

    /**
     * for
     * 1. sm2 engine decrypt
     * 2. sm2 signer sign
     *
     * @param privateKey private key with sdf index and password
     */
    public SdfECKeyParameters(SdfPrivateKey privateKey) {
        super(true);
        this.privateKey = privateKey;
    }

    public ECPoint getQ() {
        return this.publicKey.getW();
    }

    public SdfECCPublicKey getSDFECCPublicKey() {
        if (this.publicKey != null) {
            return new SdfECCPublicKey(this.publicKey.getW().getAffineX().toByteArray(),
                    this.publicKey.getW().getAffineY().toByteArray());
        } else {
            return null;
        }
    }

    public int getEcIndex() {
        return this.privateKey.getIndex();
    }

    public byte[] getPassword() {
        return this.privateKey.getPassword();
    }
}
